package com.sysdevmobile.kadmobplugin;

import android.app.Activity;
import android.view.View;
import android.widget.AbsoluteLayout;

import androidx.annotation.NonNull;

import com.google.android.gms.ads.AdListener;
import com.google.android.gms.ads.AdRequest;
import com.google.android.gms.ads.AdSize;
import com.google.android.gms.ads.AdView;
import com.google.android.gms.ads.InterstitialAd;
import com.google.android.gms.ads.MobileAds;
import com.google.android.gms.ads.initialization.InitializationStatus;
import com.google.android.gms.ads.initialization.OnInitializationCompleteListener;
import com.google.android.gms.ads.rewarded.RewardItem;
import com.google.android.gms.ads.rewarded.RewardedAd;
import com.google.android.gms.ads.rewarded.RewardedAdCallback;
import com.google.android.gms.ads.rewarded.RewardedAdLoadCallback;
import com.sysdevsolutions.external.kclientv50.KExternalEventsInterface;

import java.util.HashMap;

public class AdMobInterface {
    static private KExternalEventsInterface mEventsInterface = null;
    static private HashMap<View, AdView> mBannerList = new HashMap<View, AdView>();
    static InterstitialAd mInterstitialAd = null;
    static RewardedAd mRewardedAd = null;
    static String mRewardedAdUnitID = "";
    static String mRewardedAdInternalID = "";
    static int mRewardedAdAutoReloadWhenClosed = 0;

    static public void Initialize(Activity act, final KExternalEventsInterface eventsInterface)
    {
        mEventsInterface = eventsInterface;

        mBannerList = new HashMap<View, AdView>();

        MobileAds.initialize(act, new OnInitializationCompleteListener() {
            @Override
            public void onInitializationComplete(InitializationStatus initializationStatus) {
                eventsInterface.NotifyAllForms(new String []{"AdMob_Initialized"});
            }
        });
    }

    static public void AddBanner(Activity act, View placeholder, String unitID, final String internalID)
    {
        AbsoluteLayout al = (AbsoluteLayout)placeholder.getParent();
        AbsoluteLayout.LayoutParams lp = (AbsoluteLayout.LayoutParams)placeholder.getLayoutParams();

        AdView adView = mBannerList.get(placeholder);
        if(adView!=null)
        {
            al.removeView(adView);
            mBannerList.remove(placeholder);
        }

        if(unitID.isEmpty())
            unitID = "ca-app-pub-3940256099942544/6300978111";//Test Unit ID from Google

        adView = new AdView(act);
        //adView.setAdSize(AdSize.BANNER);
        adView.setAdSize(new AdSize(lp.width, lp.height));
        adView.setAdUnitId(unitID);

        al.addView(adView, lp);

        AdRequest adRequest = new AdRequest.Builder().build();
        adView.loadAd(adRequest);

        adView.setAdListener(new AdListener() {
            @Override
            public void onAdLoaded() {
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdLoaded", internalID});
            }

            @Override
            public void onAdFailedToLoad(int errorCode) {
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdFailedToLoad", internalID});
            }

            @Override
            public void onAdOpened() {
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdOpened", internalID});
            }

            @Override
            public void onAdClicked() {
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdClicked", internalID});
            }

            @Override
            public void onAdLeftApplication() {
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdLeftApplication", internalID});
            }

            @Override
            public void onAdClosed() {
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdClosed", internalID});
            }
        });
    }

    static public void RemoveBanner(Activity act, View placeholder)
    {
        AbsoluteLayout al = (AbsoluteLayout)placeholder.getParent();
        AbsoluteLayout.LayoutParams lp = (AbsoluteLayout.LayoutParams)placeholder.getLayoutParams();

        AdView adView = mBannerList.get(placeholder);
        if(adView!=null)
        {
            al.removeView(adView);
            mBannerList.remove(placeholder);
        }
    }

    static public void LoadInterstitial(Activity act, String unitID, final String internalID, final int autoReloadWhenClosed)
    {
        if(unitID.isEmpty())
            unitID = "ca-app-pub-3940256099942544/1033173712";//Test Unit ID from Google

        mInterstitialAd = new InterstitialAd(act);
        mInterstitialAd.setAdUnitId(unitID);
        mInterstitialAd.loadAd(new AdRequest.Builder().build());

        mInterstitialAd.setAdListener(new AdListener() {
            @Override
            public void onAdLoaded() {
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdLoaded", internalID});
            }

            @Override
            public void onAdFailedToLoad(int errorCode) {
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdFailedToLoad", internalID});
            }

            @Override
            public void onAdOpened() {
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdOpened", internalID});
            }

            @Override
            public void onAdClicked() {
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdClicked", internalID});
            }

            @Override
            public void onAdLeftApplication() {
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdLeftApplication", internalID});
            }

            @Override
            public void onAdClosed() {
                if(autoReloadWhenClosed!=0)
                    mInterstitialAd.loadAd(new AdRequest.Builder().build());
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdClosed", internalID});
            }
        });
    }

    static public void ShowInterstitial(Activity act) throws Exception
    {
        if(mInterstitialAd==null)
            throw new Exception("Ad is not loaded!");

        if(!mInterstitialAd.isLoaded())
            throw new Exception("Ad is not loaded yet!");

        mInterstitialAd.show();
    }

    static public void LoadReward(Activity act, String unitID, final String internalID, final int autoReloadWhenClosed)
    {
        if(unitID.isEmpty())
            unitID = "ca-app-pub-3940256099942544/5224354917";//Test Unit ID from Google


        mRewardedAdUnitID=unitID;
        mRewardedAdInternalID=internalID;
        mRewardedAdAutoReloadWhenClosed=autoReloadWhenClosed;

        mRewardedAd = new RewardedAd(act, unitID);

        RewardedAdLoadCallback adLoadCallback = new RewardedAdLoadCallback() {
            @Override
            public void onRewardedAdLoaded() {
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdLoaded", internalID});
            }

            @Override
            public void onRewardedAdFailedToLoad(int errorCode) {
                mRewardedAd=null;
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdFailedToLoad", internalID});
            }
        };
        mRewardedAd.loadAd(new AdRequest.Builder().build(), adLoadCallback);


    }

    static public void ShowReward(final Activity act) throws Exception
    {
        final String internalID = mRewardedAdInternalID;

        if(mRewardedAd==null)
            throw new Exception("Ad is not loaded!");

        if(!mRewardedAd.isLoaded())
            throw new Exception("Ad is not loaded yet!");

        RewardedAdCallback adCallback = new RewardedAdCallback() {
            @Override
            public void onRewardedAdOpened() {
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdOpened", internalID});
            }

            @Override
            public void onRewardedAdClosed() {
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdClosed", internalID});
                if(mRewardedAdAutoReloadWhenClosed!=0)
                    LoadReward(act, mRewardedAdUnitID, mRewardedAdInternalID, mRewardedAdAutoReloadWhenClosed);
            }

            @Override
            public void onUserEarnedReward(@NonNull RewardItem reward) {
                mEventsInterface.NotifyAllForms(new String []{"AdMob_UserEarnedReward", internalID, String.valueOf(reward.getAmount())});
            }

            @Override
            public void onRewardedAdFailedToShow(int errorCode) {
                mEventsInterface.NotifyAllForms(new String []{"AdMob_AdFailedToShow", internalID});
                if(mRewardedAdAutoReloadWhenClosed!=0)
                    LoadReward(act, mRewardedAdUnitID, mRewardedAdInternalID, mRewardedAdAutoReloadWhenClosed);
            }
        };

        mRewardedAd.show(act, adCallback);
    }
}
